# Security Policy

## Reporting a Vulnerability

Please email any security vulnerabilities to ben@benfrederickson.com.

## Supported Versions

Only the most recent version of py-spy will get security updates.
